@@ -1,4 +1,4 @@
-from .actions import transfer, add_contact, show_all_contact, show_contact_by_name, show_authorized_tokens, authorize_token
+from .actions import transfer, add_contact, show_all_contact, show_contact_by_name, show_authorized_tokens, authorize_token, delete_contact, edit_contact
 from .utils import contact_tool
 from .json_reader import JSONReader
 
@@ -10,5 +10,7 @@ __all__ = [
     'contact_tool',
     'authorize_token',
     'show_authorized_tokens',
-    'JSONReader'
+    'JSONReader',
+    'delete_contact',
+    'edit_contact'
 ]
\ No newline at end of file
