@@ -1,6 +1,6 @@
 from web3 import Web3
 
-from actions_lib.actions.transfer.transfer import ALLOWANCE_ABI, CHAIN_ID_MAPPING, ERC20_APPROVE_ABI, get_web3, TOKEN_MAPPING
+from actions_lib.actions.transfer.transfer import ALLOWANCE_ABI, CHAIN_ID_MAPPING, ERC20_APPROVE_ABI, convert_to_wei, get_web3, TOKEN_MAPPING
 from actions_lib.actions.type import Action, ActionData
 
 SUPPORTED_TOKENS = {
@@ -30,11 +30,15 @@ def authorize_token(token, amount, step: any, **kwargs):
     spender_address = spender_info[chain_raw]['control_address']
 
     w3 = get_web3(providers, chain_raw)
-    amount_to_transfer = w3.to_wei(float(amount), 'mwei')
+    amount_to_transfer = convert_to_wei(float(amount), chain_raw, token.lower())
+    
+    token_address = TOKEN_MAPPING[chain_raw][token.lower()]['address']
+    if token_address is not None:
+        token_address = w3.to_checksum_address(token_address)
     action_params = {
         "func": "approve",
         "chainId": CHAIN_ID_MAPPING[chain_raw],
-        'contract': TOKEN_MAPPING[chain_raw][token.lower()],
+        'contract': token_address,
         '_spender': spender_address,
         '_value': amount_to_transfer,
         'abi': ERC20_APPROVE_ABI
