@@ -69,6 +69,14 @@ TOKEN_MAPPING = {
             "address": "0x2260FAC5E5542a773Aa44fBCfeDf7C193bc2C599",
             "decimal": 8
         },
+        "wbtc": {
+            "address": "0x2260FAC5E5542a773Aa44fBCfeDf7C193bc2C599",
+            "decimal": 8
+        },
+        "cbbtc": {
+            "address": "0x2260FAC5E5542a773Aa44fBCfeDf7C193bc2C599",
+            "decimal": 8
+        },
         "ens": {
             "address": "0xC18360217D8F7Ab5e7c516566761Ea12Ce7F9D72",
             "decimal": 18
@@ -87,9 +95,13 @@ TOKEN_MAPPING = {
             "address": "0xcbB7C0000aB88B473b1f5aFd9ef808440eed33Bf",
             "decimal": 8
         },
-        "aero": {
-            "address": "0x940181a94A35A4569E4529A3CDfB74e38FD98631",
-            "decimal": 18
+        "wbtc": {
+            "address": "0xcbB7C0000aB88B473b1f5aFd9ef808440eed33Bf",
+            "decimal": 8
+        },
+        "cbbtc": {
+            "address": "0xcbB7C0000aB88B473b1f5aFd9ef808440eed33Bf",
+            "decimal": 8
         }
     },
 }
@@ -133,6 +145,15 @@ def get_web3(providers, chain):
         providers[chain]['w3'] = Web3(HTTPProvider(providers[chain]['rpc']))
     return providers[chain]['w3']
 
+def get_user_action_mode(redis_client, user_id):
+    user_id = user_id.lower()
+    action_mode_key = f"user:{user_id}:action_mode"
+    mode = redis_client.get(action_mode_key)
+    if mode:
+        return mode
+    else:
+        return 'manual'
+
 def convert_to_wei(amount, chain, token):
     decimal = TOKEN_MAPPING[chain][token.lower()]['decimal']
     amount = float(amount) * (10 ** decimal)
@@ -143,8 +164,8 @@ def convert_to_value(amount, chain, token):
     amount = amount / (10 ** decimal)
     return float(amount)
 
-def transfer(receiver: str, amount: float, step: any, run_mode: str = 'auto', chain: str = "base", token: str = "usdc", **kwargs: Any) -> Dict[str, Any]:
-    print(f"receiver: {receiver}, amount: {amount}, run_mode: {run_mode}, chain: {chain}, token: {token}, kwargs: {kwargs}, step: {step}")
+def transfer(receiver: str, amount: float, step: any, chain: str = "base", token: str = "usdc", **kwargs: Any) -> Dict[str, Any]:
+    print(f"receiver: {receiver}, amount: {amount}, chain: {chain}, token: {token}, kwargs: {kwargs}, step: {step}")
     
     chain_raw = chain.lower()
     executor = kwargs.get("executor")
@@ -152,6 +173,7 @@ def transfer(receiver: str, amount: float, step: any, run_mode: str = 'auto', ch
     spender_info = kwargs.get('spender')
     providers = kwargs.get("providers")
     executor_balance = kwargs.get("executor_balance")
+    run_mode = get_user_action_mode(redis_client, executor)
 
     if not providers or chain_raw not in providers:
         raise ValueError(f"Provider for chain {chain} not found")
@@ -168,7 +190,6 @@ def transfer(receiver: str, amount: float, step: any, run_mode: str = 'auto', ch
     if token_address is not None:
         token_address = w3.to_checksum_address(token_address)
     print(f"token address: {token_address}", flush=True)
-    print(f"token address: {token_address is None}", flush=True)
     
     print(f"w3: {w3}", flush=True)
 
@@ -180,7 +201,7 @@ def transfer(receiver: str, amount: float, step: any, run_mode: str = 'auto', ch
 def handle_auto_transfer(w3: Web3, eth_w3, executor, receiver, amount, token_address, spender_address, sender_address, control_contract, private_key, redis_client, chain_raw, token_raw, blockchain_explore, executor_balance):
     if token_raw != 'usdc':
         token = token_raw.upper()
-        if token_raw == 'btc':
+        if token_raw in ['btc', 'cbbtc', 'wbtc']:
             if chain_raw == 'base':
                 token = 'cbBTC'
             else:
@@ -219,7 +240,7 @@ def handle_auto_transfer(w3: Web3, eth_w3, executor, receiver, amount, token_add
                 }
                 return {'result': info, 'action': None, 'next_action': None}
             else:
-                return {'result': {"code": 500, "content": "Insufficient balance. Estimated gas cost exceed account balance"}, 'action': None, 'next_action': None}
+                return {'result': {"code": 402, "content": "Your account balance is insufficient, please top up first or apply to join the credit list for getting free $5 funding."}, 'action': None, 'next_action': None}
         except Exception as e:
             return handle_transaction_error(e, control_contract, w3)
 
